@@ -1,4 +1,5 @@
 use super::*;
+use crate::nodes::{EmailLink, HyperLink, ImageLink, TagReference, TwoWayLink};
 
 impl Display for SmartLink {
     fn fmt(&self, f: &mut Formatter) -> fmt::Result {
@@ -27,11 +28,41 @@ impl Display for SmartLink {
             //         (Some(bind), Some(alt)) => write!(f, "{}[{}:{}]", img_to, bind, alt),
             //     }
             // }
-            Self::Reference { .. } => unimplemented!(),
-            Self::Image(_) => unimplemented!(),
-            Self::Normal(_) => unimplemented!(),
-            Self::EMail(_) => unimplemented!(),
-            Self::TwoWay(_) => unimplemented!(),
+            Self::Reference(v) => Display::fmt(v, f),
+            Self::Image(v) => Display::fmt(v, f),
+            Self::Normal(v) => Display::fmt(v, f),
+            Self::EMail(v) => Display::fmt(v, f),
+            Self::TwoWay(v) => Display::fmt(v, f),
         }
     }
 }
+
+impl Display for EmailLink {
+    fn fmt(&self, _: &mut Formatter<'_>) -> fmt::Result {
+        todo!()
+    }
+}
+
+impl Display for TagReference {
+    fn fmt(&self, _: &mut Formatter<'_>) -> fmt::Result {
+        todo!()
+    }
+}
+
+impl Display for ImageLink {
+    fn fmt(&self, _: &mut Formatter<'_>) -> fmt::Result {
+        todo!()
+    }
+}
+
+impl Display for HyperLink {
+    fn fmt(&self, _: &mut Formatter<'_>) -> fmt::Result {
+        todo!()
+    }
+}
+
+impl Display for TwoWayLink {
+    fn fmt(&self, _: &mut Formatter<'_>) -> fmt::Result {
+        todo!()
+    }
+}
